"""
Development settings for server project.
"""

import os
import yaml
from django.utils.translation import ugettext as _
from django.utils.translation import gettext_lazy as _

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

def djangoldp_config():

    """Get DjangoLDP parameters from configuration file"""

    path = os.path.join(BASE_DIR, 'packages.yml')
    with open(path, 'r') as f:
        content = yaml.safe_load(f)
        config = content.get('server', {})
        try:
            config['packages'] = list(content.get('ldppackages').keys())
        except AttributeError:
            config['packages'] = []
        return config


DJANGOLDP_PACKAGES = djangoldp_config().get('packages', [])

SECRET_KEY = 'wr1tfli=&(oervg-g8_6*zlrnny=yha^+smg$zq@h@#9lmi%p2'
DEBUG = True
if 'localhost' in djangoldp_config().get('site_url'):
    ALLOWED_HOSTS = []
####################################################
##########  PRODUCTION CHANGES ################
####################################################

# Add the domain name of all your hosts below
# By default, the site url in packages.yml is added
else:    
    ALLOWED_HOSTS = [djangoldp_config().get('site_url').replace('https://','')]
print("Settings.py - allowed hosts are : ",ALLOWED_HOSTS)
# DOMAINE NAME
# By default, the site url in packages.yml is used
# if you're using a sub-domain, make sure to include it ('https://subdomain.example.org')
INSTANCE_DOMAINE_NAME = djangoldp_config().get('site_url')
# It will be used to :
# - Build the shortlinks of your actions
# - Save the emails sent to reprensentatives to your database (important for federation)

# ORGANISATION NAME
# Add the name of your organisation below
# It will be displayed next to your action on other instances
INSTANCE_NAME = "Your organisation name"

# FEDERATION
# Make 'True' to activate federation and display changes on the template 
FEDERATION_ACTIVE = False


# Financing Risefor
# Display ongoing campaigns to improve risefor
# You can select which campaigns are displayed within the Back Office
CAMPAIGN_FINANCING = True



############
# ACTIVATE HTTPS
############
# Uncomment 4 lines below to activate
 
#SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')
#SECURE_SSL_REDIRECT = True
#SESSION_COOKIE_SECURE = True
#CSRF_COOKIE_SECURE = True

############
# ACTIVATE MULTI-LINGUAL TEMPLATE
############
#default languages 
# For Non international : must also be changed in 'else' below
LANGUAGE_CODE = 'fr'
MODELTRANSLATION_DEFAULT_LANGUAGE = 'fr'
TIME_ZONE = 'UTC'
#add country prefix by default, make True to active
prefix_default_language = False


#Make True to activate international template
INTERNATIONAL_TEMPLATE = False

if INTERNATIONAL_TEMPLATE == True:
    #Add wanted languages below
    LANGUAGES = (
        ('en', ('English-Global')),
        ('us', ('English-USA')),
        ('fr', ('French')),
        ('es', ('Spanish')),
    )
    COUNTRIES_OVERRIDE = {
        'Global': {
            'name': _('Global'),
            'code':_('en')
        },
    }
else: 
    LANGUAGES = (
        #change default language below
        ('fr', ('French')),
    )
#for django, don't touch
USE_I18N = True
USE_L10N = True
USE_TZ = True
COUNTRIES_FLAG_URL = '/static/flags/img/{code}.svg'
LOCALE_PATHS = (
    os.path.join(BASE_DIR, 'locale'),
)

# Application definition
WSGI_APPLICATION = 'server.wsgi.application'
INSTALLED_APPS = list(DJANGOLDP_PACKAGES)
INSTALLED_APPS.extend([
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'djangoldp',
    'guardian',
    'django_admin_logs',
])
ROOT_URLCONF = 'server.urls'
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'risefor_lobbying.context_processors.internationalTemplate',
                'risefor_lobbying.context_processors.instanceInformation',
                'risefor_lobbying.context_processors.federationStatus',
                'risefor_lobbying.context_processors.displayCampaignFinancing',
            ],
        },
    },
]

dataBaseType = 'dev or postgresql'
if dataBaseType == 'dev':
    # Database
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.sqlite3',
            'NAME': os.path.join(BASE_DIR, 'db.sqlite3'),
        }
    }
#use other db
elif dataBaseType == 'postgresql':
    DATABASES = {
        'default': {
            'ENGINE': 'django.db.backends.postgresql',
            'NAME': 'database_name',
            'USER': 'user_name',
            'PASSWORD': 'user_password',
            'HOST': 'backend_url',
            'PORT': '',
        }
    }
else:
    raise ValueError("Choose type of database :",dataBaseType," in file settings.py")


# Authentication

AUTH_PASSWORD_VALIDATORS = []
AUTH_USER_MODEL = 'djangoldp_account.LDPUser'
LOGIN_REDIRECT_URL = '/'

if 'djangoldp_account' in INSTALLED_APPS:
    LOGIN_URL = '/auth/login/'
    OIDC_USERINFO = 'djangoldp_account.settings.userinfo'
    OIDC_REGISTRATION_ENDPOINT_REQ_TOKEN = False
    OIDC_REGISTRATION_ENDPOINT_ALLOW_HTTP_ORIGIN = True
    OIDC_IDTOKEN_SUB_GENERATOR = 'djangoldp_account.settings.sub_generator'
    OIDC_IDTOKEN_EXPIRE = 60 * 60 * 1600
    AUTH_USER_MODEL = 'djangoldp_account.LDPUser'
    MIDDLEWARE = [
        'django.middleware.security.SecurityMiddleware',
        'django.contrib.sessions.middleware.SessionMiddleware',
        #if activate cache, put it after localMiddleaware
        'django.middleware.locale.LocaleMiddleware',
        'django.middleware.common.CommonMiddleware',
        'django.middleware.csrf.CsrfViewMiddleware',
        'django.contrib.auth.middleware.AuthenticationMiddleware',
        'django.contrib.messages.middleware.MessageMiddleware',
        'django.middleware.clickjacking.XFrameOptionsMiddleware',
        'djangoldp_account.auth.middleware.JWTUserMiddleware'
    ]
    AUTHENTICATION_BACKENDS = [
        'djangoldp_account.auth.backends.EmailOrUsernameAuthBackend',
        'guardian.backends.ObjectPermissionBackend',
        'djangoldp_account.auth.backends.ExternalUserBackend'
    ]
else:
    MIDDLEWARE = [
        'django.middleware.security.SecurityMiddleware',
        'django.contrib.sessions.middleware.SessionMiddleware',
        #if activate cache, put it after localMiddleaware
        'django.middleware.locale.LocaleMiddleware',
        'django.middleware.common.CommonMiddleware',
        'django.middleware.csrf.CsrfViewMiddleware',
        'django.contrib.auth.middleware.AuthenticationMiddleware',
        'django.contrib.messages.middleware.MessageMiddleware',
        'django.middleware.clickjacking.XFrameOptionsMiddleware',
    ]
    AUTHENTICATION_BACKENDS = ['django.contrib.auth.backends.ModelBackend', 'guardian.backends.ObjectPermissionBackend']

if 'djangoldp_notification' in INSTALLED_APPS:
    MIDDLEWARE.append('djangoldp_notification.middlewares.CurrentUserMiddleware')

USER_ANONYMOUS_PERMISSIONS=['add', 'view']
USER_AUTHENTICATED_PERMISSIONS=['view', 'add']
USER_OWNER_PERMISSIONS=['view', 'add', 'change']

GROUP_ANONYMOUS_PERMISSIONS=['view']
GROUP_AUTHENTICATED_PERMISSIONS=['view', 'add', 'change']
GROUP_OWNER_PERMISSIONS=['view', 'add', 'change']

ANONYMOUS_USER_NAME = None

# Static files (CSS, JavaScript, Images)
APPEND_SLASH = False
SITE_URL = djangoldp_config().get('site_url') 
BASE_URL = SITE_URL
print("Website url is : ",BASE_URL,SITE_URL)
STATIC_URL = '/static/'
STATIC_DIR = os.path.join(BASE_DIR, 'static')
STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static'), ]
MEDIA_URL = '/media/'
MEDIA_ROOT = os.path.join(BASE_DIR, 'media')
MEDIAFILES_DIRS = [os.path.join(BASE_DIR, 'media'), ]
LDP_RDF_CONTEXT = 'https://cdn.happy-dev.fr/owl/hdcontext.jsonld'

# Chat
PROSODY_HTTP_URL = djangoldp_config().get('xmpp_url')
JABBER_DEFAULT_HOST = djangoldp_config().get('jabber_host')

# Email
EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"
if DEBUG:
    EMAIL_HOST = 'localhost'
    EMAIL_PORT = 1025
    EMAIL_HOST_USER = ''
    EMAIL_HOST_PASSWORD = ''
    EMAIL_USE_TLS = False
    DEFAULT_FROM_EMAIL = 'testing@example.com'
####
# Production - Uncomment & inform below
####
"""
EMAIL_BACKEND = 'django.core.mail.backends.smtp.EmailBackend'
EMAIL_HOST_USER = ''
EMAIL_HOST_PASSWORD = ''
EMAIL_HOST = ''
EMAIL_USE_TLS = True
EMAIL_PORT = 587
DEFAULT_FROM_EMAIL = ''
"""

# Registration
ACCOUNT_ACTIVATION_DAYS = 3  # days
REGISTRATION_FIELDS = ('first_name', 'last_name', 'email', 'username', 'password1', 'password2')
EMAIL_ON_ACCOUNT_CREATION = False

#Admin log
DJANGO_ADMIN_LOGS_ENABLED = True
